@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "magik-company" "1.1.1"
+(define-package "magik-company" "20250922.1311"
   "Magik backend for company-mode."
   '((emacs      "29.1")
     (magik-mode "0.5.1")
